import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { TypeOrmModule } from '@nestjs/typeorm';

import { AuthModule } from './auth/auth.module';
import { BcryptModule } from './bcrypt/bcrypt.module';
import { CarreraModule } from './carrera/carrera.module';
import { CarreraProgramaModule } from './carrera-programa/carrera-programa.module';
import { CarritoModule } from './carrito/carrito.module';
import { CronModule } from './cron/cron.module';
import { EquipoModule } from './equipo/equipo.module';
import { HoraExcepcionModule } from './hora-excepcion/hora-excepcion.module';
import { InstitucionModule } from './institucion/institucion.module';
import { InstitucionCarreraModule } from './institucion-carrera/institucion-carrera.module';
import { InstitucionDiaModule } from './institucion-dia/institucion-dia.module';
import { InstitucionInfraccionModule } from './institucion-infraccion/institucion-infraccion.module';
import { InstitucionTipoCarritoModule } from './institucion-tipo-carrito/institucion-tipo-carrito.module';
import { ModuloModule } from './modulo/modulo.module';
import { MotivoModule } from './motivo/motivo.module';
import { MultaModule } from './multa/multa.module';
import { NodemailerModule } from './nodemailer/nodemailer.module';
import { OperadorModule } from './operador/operador.module';
import { PrestamoModule } from './prestamo/prestamo.module';
import { ProgramaModule } from './programa/programa.module';
import { StatusModule } from './status/status.module';
import { TipoEntradaModule } from './tipo-entrada/tipo-entrada.module';
import { TipoUsuarioModule } from './tipo-usuario/tipo-usuario.module';
import { UploadFileModule } from './upload-file/upload-file.module';
import { UsuarioModule } from './usuario/usuario.module';

import { Carrera } from './carrera/entity/carrera.entity';
import { CarreraPrograma } from './carrera-programa/entity/carrera-programa.entity';
import { Carrito } from './carrito/entity/carrito.entity';
import { Dia } from './institucion-dia/entity/dia.entity';
import { Equipo } from './equipo/entity/equipo.entity';
import { EquipoTipoEntrada } from './equipo/entity/equipo-tipo-entrada.entity';
import { HoraExcepcion } from './hora-excepcion/entity/hora-excepcion.entity';
import { Infraccion } from './institucion-infraccion/entity/infraccion.entity';
import { Institucion } from './institucion/entity/institucion.entity';
import { InstitucionCarrera } from './institucion-carrera/entity/institucion-carrera.entity';
import { InstitucionDia } from './institucion-dia/entity/institucion-dia.entity';
import { InstitucionInfraccion } from './institucion-infraccion/entity/institucion-infraccion.entity';
import { InstitucionTipoCarrito } from './institucion-tipo-carrito/entity/institucion-tipo-carrito.entity';
import { Modulo } from './modulo/entity/modulo.entity';
import { Motivo } from './motivo/entity/motivo.entity';
import { Multa } from './multa/entity/multa.entity';
import { Nivel } from './institucion-carrera/entity/nivel.entity';
import { Operador } from './operador/entity/operador.entity';
import { Prestamo } from './prestamo/entity/prestamo.entity';
import { Programa } from './programa/entity/programa.entity';
import { Status } from './status/entity/status.entity';
import { TipoCarrito } from './institucion-tipo-carrito/entity/tipo-carrito.entity';
import { TipoEntrada } from './tipo-entrada/entity/tipo-entrada.entity';
import { TipoUsuario } from './tipo-usuario/entity/tipo-usuario.entity';
import { Usuario } from './usuario/entity/usuario.entity';

@Module({
  imports: [
    ConfigModule.forRoot({ isGlobal: true }),
    TypeOrmModule.forRootAsync({
      inject: [ConfigService],
      useFactory: (configService: ConfigService) => {
        return {
          type: 'mariadb',
          host: configService.get<string>('DB_HOST'),
          database: configService.get<string>('DB'),
          username: configService.get<string>('DB_USER'),
          password: configService.get<string>('DB_PASSWORD'),
          port: Number(configService.get<string>('DB_PORT')),
          synchronize: true,
          entities: [
            Carrera,
            CarreraPrograma,
            Carrito,
            Dia,
            Equipo,
            EquipoTipoEntrada,
            HoraExcepcion,
            Infraccion,
            Institucion,
            InstitucionCarrera,
            InstitucionDia,
            InstitucionInfraccion,
            InstitucionTipoCarrito,
            Modulo,
            Motivo,
            Multa,
            Nivel,
            Operador,
            Prestamo,
            Programa,
            Status,
            TipoCarrito,
            TipoEntrada,
            TipoUsuario,
            Usuario,
          ],
        };
      },
    }),
    AuthModule,
    BcryptModule,
    CarreraModule,
    CarreraProgramaModule,
    CarritoModule,
    CronModule,
    EquipoModule,
    HoraExcepcionModule,
    InstitucionModule,
    InstitucionCarreraModule,
    InstitucionDiaModule,
    InstitucionInfraccionModule,
    InstitucionTipoCarritoModule,
    ModuloModule,
    MotivoModule,
    MultaModule,
    NodemailerModule,
    OperadorModule,
    PrestamoModule,
    ProgramaModule,
    StatusModule,
    TipoEntradaModule,
    TipoUsuarioModule,
    UploadFileModule,
    UsuarioModule,
  ],
})
export class AppModule {}
