import { Column, Entity, OneToMany, PrimaryGeneratedColumn } from 'typeorm';
import { InstitucionCarrera } from '../../institucion-carrera/entity/institucion-carrera.entity';
import { InstitucionDia } from '../../institucion-dia/entity/institucion-dia.entity';
import { InstitucionInfraccion } from '../../institucion-infraccion/entity/institucion-infraccion.entity';
import { InstitucionTipoCarrito } from '../../institucion-tipo-carrito/entity/institucion-tipo-carrito.entity';
import { Modulo } from '../../modulo/entity/modulo.entity';
import { Operador } from '../../operador/entity/operador.entity';
import { Usuario } from '../../usuario/entity/usuario.entity';

@Entity()
export class Institucion {
  @PrimaryGeneratedColumn()
  id_institucion: number;

  @Column({ type: Boolean, nullable: true, default:false })
  activo: boolean;

  @Column({ type: String, nullable: true, length: 4 })
  clave: string;

  @Column({ type: Number, nullable: false, default: 7 })
  dias_multa_retraso: number;

  @Column({ type: String, nullable: false, length: 150 })
  institucion: string;

  @Column({ type: String, nullable: true, length: 60 })
  logo: string;

  @Column({ type: String, nullable: true, length: 40 })
  responsable: string;

  @Column({ type: String, nullable: true, length: 10 })
  telefono: string;

  @Column({ type: Number, nullable: false, default: 15 })
  tiempo_entrega: number;

  @Column({ type: Number, nullable: false, default: 120 })
  tiempo_prestamo: number;

  @Column({ type: Number, nullable: false, default: 10 })
  tiempo_recoger: number;

  @Column({ type: String, nullable: true, length: 60 })
  ubicacion: string;

  @OneToMany(() => InstitucionCarrera, (carrera) => carrera.institucion)
  carreras: InstitucionCarrera[];

  @OneToMany(
    () => InstitucionDia,
    (institucionDia) => institucionDia.institucion,
  )
  institucionDias: InstitucionDia[];

  @OneToMany(
    () => InstitucionInfraccion,
    (institucionInfraccion) => institucionInfraccion.institucion,
  )
  institucionInfracciones: InstitucionInfraccion[];

  @OneToMany(
    () => InstitucionTipoCarrito,
    (institucionTipoCarrito) => institucionTipoCarrito.institucion,
  )
  institucionTiposCarritos: InstitucionTipoCarrito[];

  @OneToMany(() => Modulo, (modulo) => modulo.institucion)
  modulos: Modulo[];

  @OneToMany(() => Operador, (operador) => operador.institucion)
  operadores: Operador[];

  @OneToMany(() => Usuario, (usuario) => usuario.institucion)
  usuarios: Usuario[];
}
